<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Reset</name>
    <message>
        <location filename="../ResetInit.js" line="+5"/>
        <source>Reset</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Wyzeruj
Przywróć domyślną wartość &apos;%1&apos; w &apos;%2&apos;</translatorcomment>
        <translation>Stan początkowy</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Reset / Idle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Przywróć stan początkowy</translation>
    </message>
</context>
</TS>
